==> glibc-2.0.4.tgz: install/doinst.sh <==
( cd usr/lib ; rm -rf libc.so )
( cd usr/lib ; ln -sf glibc.so libc.so )
( cd usr/lib ; rm -rf libdb.so.2 )
( cd usr/lib ; ln -sf libdb.so.2.0.0 libdb.so.2 )
( cd usr/lib ; rm -rf libdb.so )
( cd usr/lib ; ln -sf ../../lib/libdb.so.2 libdb.so )
( cd usr/lib ; rm -rf libm.so )
( cd usr/lib ; ln -sf ../../lib/libm.so.6 libm.so )
( cd usr/lib ; rm -rf libBrokenLocale.so )
( cd usr/lib ; ln -sf ../../lib/libBrokenLocale.so.1 libBrokenLocale.so )
( cd usr/lib ; rm -rf libutil.so )
( cd usr/lib ; ln -sf ../../lib/libutil.so.1 libutil.so )
( cd usr/lib ; rm -rf libcrypt.so )
( cd usr/lib ; ln -sf ../../lib/libcrypt.so.1 libcrypt.so )
( cd usr/lib ; rm -rf libnss_files.so )
( cd usr/lib ; ln -sf ../../lib/libnss_files.so.1 libnss_files.so )
( cd usr/lib ; rm -rf libnss_db.so )
( cd usr/lib ; ln -sf ../../lib/libnss_db.so.1 libnss_db.so )
( cd usr/lib ; rm -rf libresolv.so )
( cd usr/lib ; ln -sf ../../lib/libresolv.so.2 libresolv.so )
( cd usr/lib ; rm -rf libnss_dns.so )
( cd usr/lib ; ln -sf ../../lib/libnss_dns.so.1 libnss_dns.so )
( cd usr/lib ; rm -rf libnss_nis.so )
( cd usr/lib ; ln -sf ../../lib/libnss_nis.so.1 libnss_nis.so )
( cd usr/lib ; rm -rf libnsl.so )
( cd usr/lib ; ln -sf ../../lib/libnsl.so.1 libnsl.so )
( cd usr/lib ; rm -rf libnss_compat.so )
( cd usr/lib ; ln -sf ../../lib/libnss_compat.so.1 libnss_compat.so )
( cd usr/lib ; rm -rf libpthread.so )
( cd usr/lib ; ln -sf ../../lib/libpthread.so.0 libpthread.so )
( cd usr/lib ; rm -rf libdl.so )
( cd usr/lib ; ln -sf ../../lib/libdl.so.2 libdl.so )
( cd usr/share ; rm -rf zoneinfo )
( cd usr/share ; ln -sf /usr/lib/zoneinfo zoneinfo )
( cd usr/include ; rm -rf linux )
( cd usr/include ; ln -sf /usr/src/linux/include/linux linux )
( cd usr/include ; rm -rf asm )
( cd usr/include ; ln -sf /usr/src/linux/include/asm asm )
( cd usr/include ; rm -rf scsi )
( cd usr/include ; ln -sf /usr/src/linux/include/scsi scsi )
( cd lib ; rm -rf libBrokenLocale.so.1 )
( cd lib ; ln -sf libBrokenLocale-2.0.4.so libBrokenLocale.so.1 )
( cd lib ; rm -rf libc.so.6 )
( cd lib ; ln -sf libc-2.0.4.so libc.so.6 )
( cd lib ; rm -rf libdb.so.2 )
( cd lib ; ln -sf libdb-2.0.4.so libdb.so.2 )
( cd lib ; rm -rf libm.so.6 )
( cd lib ; ln -sf libm-2.0.4.so libm.so.6 )
( cd lib ; rm -rf libutil.so.1 )
( cd lib ; ln -sf libutil-2.0.4.so libutil.so.1 )
( cd lib ; rm -rf libcrypt.so.1 )
( cd lib ; ln -sf libcrypt-2.0.4.so libcrypt.so.1 )
( cd lib ; rm -rf libnss_files.so.1 )
( cd lib ; ln -sf libnss_files-2.0.4.so libnss_files.so.1 )
( cd lib ; rm -rf libnss_db.so.1 )
( cd lib ; ln -sf libnss_db-2.0.4.so libnss_db.so.1 )
( cd lib ; rm -rf libresolv.so.2 )
( cd lib ; ln -sf libresolv-2.0.4.so libresolv.so.2 )
( cd lib ; rm -rf libnss_dns.so.1 )
( cd lib ; ln -sf libnss_dns-2.0.4.so libnss_dns.so.1 )
( cd lib ; rm -rf libnsl.so.1 )
( cd lib ; ln -sf libnsl-2.0.4.so libnsl.so.1 )
( cd lib ; rm -rf libnss_nis.so.1 )
( cd lib ; ln -sf libnss_nis-2.0.4.so libnss_nis.so.1 )
( cd lib ; rm -rf libnss_compat.so.1 )
( cd lib ; ln -sf libnss_compat-2.0.4.so libnss_compat.so.1 )
( cd lib ; rm -rf libpthread.so.0 )
( cd lib ; ln -sf libpthread-0.6.so libpthread.so.0 )
( cd lib ; rm -rf libdl.so.2 )
( cd lib ; ln -sf libdl-2.0.4.so libdl.so.2 )
( cd lib ; rm -rf ld-linux.so.2 )
( cd lib ; ln -sf ld-2.0.4.so ld-linux.so.2 )

==> glibc-2.0.7pre6.tgz: install/doinst.sh <==
( cd etc ; rm -rf localtime )
( cd etc ; ln -sf ../usr/share/zoneinfo/Factory localtime )
( cd lib ; rm -rf ld-linux.so.2 )
( cd lib ; ln -sf ld-2.0.7.so ld-linux.so.2 )
( cd lib ; rm -rf libBrokenLocale.so.1 )
( cd lib ; ln -sf libBrokenLocale-2.0.7.so libBrokenLocale.so.1 )
( cd lib ; rm -rf libc.so.6 )
( cd lib ; ln -sf libc-2.0.7.so libc.so.6 )
( cd lib ; rm -rf libcrypt.so.1 )
( cd lib ; ln -sf libcrypt-2.0.7.so libcrypt.so.1 )
( cd lib ; rm -rf libdb.so.2 )
( cd lib ; ln -sf libdb-2.0.7.so libdb.so.2 )
( cd lib ; rm -rf libdl.so.2 )
( cd lib ; ln -sf libdl-2.0.7.so libdl.so.2 )
( cd lib ; rm -rf libm.so.6 )
( cd lib ; ln -sf libm-2.0.7.so libm.so.6 )
( cd lib ; rm -rf libnsl.so.1 )
( cd lib ; ln -sf libnsl-2.0.7.so libnsl.so.1 )
( cd lib ; rm -rf libnss_compat.so.1 )
( cd lib ; ln -sf libnss_compat-2.0.7.so libnss_compat.so.1 )
( cd lib ; rm -rf libnss_db.so.1 )
( cd lib ; ln -sf libnss_db-2.0.7.so libnss_db.so.1 )
( cd lib ; rm -rf libnss_dns.so.1 )
( cd lib ; ln -sf libnss_dns-2.0.7.so libnss_dns.so.1 )
( cd lib ; rm -rf libnss_files.so.1 )
( cd lib ; ln -sf libnss_files-2.0.7.so libnss_files.so.1 )
( cd lib ; rm -rf libnss_nis.so.1 )
( cd lib ; ln -sf libnss_nis-2.0.7.so libnss_nis.so.1 )
( cd lib ; rm -rf libpthread.so.0 )
( cd lib ; ln -sf libpthread-0.7.so libpthread.so.0 )
( cd lib ; rm -rf libresolv.so.2 )
( cd lib ; ln -sf libresolv-2.0.7.so libresolv.so.2 )
( cd lib ; rm -rf libutil.so.1 )
( cd lib ; ln -sf libutil-2.0.7.so libutil.so.1 )
( cd usr/lib ; rm -rf libBrokenLocale.so )
( cd usr/lib ; ln -sf ../../lib/libBrokenLocale.so.1 libBrokenLocale.so )
( cd usr/lib ; rm -rf libcrypt.so )
( cd usr/lib ; ln -sf ../../lib/libcrypt.so.1 libcrypt.so )
( cd usr/lib ; rm -rf libdb.so )
( cd usr/lib ; ln -sf ../../lib/libdb.so.2 libdb.so )
( cd usr/lib ; rm -rf libdl.so )
( cd usr/lib ; ln -sf ../../lib/libdl.so.2 libdl.so )
( cd usr/lib ; rm -rf libm.so )
( cd usr/lib ; ln -sf ../../lib/libm.so.6 libm.so )
( cd usr/lib ; rm -rf libndbm.a )
( cd usr/lib ; ln -sf libdb.a libndbm.a )
( cd usr/lib ; rm -rf libndbm.so )
( cd usr/lib ; ln -sf libdb.so libndbm.so )
( cd usr/lib ; rm -rf libnsl.so )
( cd usr/lib ; ln -sf ../../lib/libnsl.so.1 libnsl.so )
( cd usr/lib ; rm -rf libnss_compat.so )
( cd usr/lib ; ln -sf ../../lib/libnss_compat.so.1 libnss_compat.so )
( cd usr/lib ; rm -rf libnss_db.so )
( cd usr/lib ; ln -sf ../../lib/libnss_db.so.1 libnss_db.so )
( cd usr/lib ; rm -rf libnss_dns.so )
( cd usr/lib ; ln -sf ../../lib/libnss_dns.so.1 libnss_dns.so )
( cd usr/lib ; rm -rf libnss_files.so )
( cd usr/lib ; ln -sf ../../lib/libnss_files.so.1 libnss_files.so )
( cd usr/lib ; rm -rf libnss_nis.so )
( cd usr/lib ; ln -sf ../../lib/libnss_nis.so.1 libnss_nis.so )
( cd usr/lib ; rm -rf libpthread.so )
( cd usr/lib ; ln -sf ../../lib/libpthread.so.0 libpthread.so )
( cd usr/lib ; rm -rf libresolv.so )
( cd usr/lib ; ln -sf ../../lib/libresolv.so.2 libresolv.so )
( cd usr/lib ; rm -rf libutil.so )
( cd usr/lib ; ln -sf ../../lib/libutil.so.1 libutil.so )
